@@ -34,8 +34,8 @@ struct passwd
 {
     char *pw_name;
     char *pw_passwd;
-    int pw_uid;
-    int pw_gid;
+    uid_t pw_uid;
+    gid_t pw_gid;
     char *pw_gecos;
     char *pw_dir;
     char *pw_shell;
@@ -53,34 +53,34 @@ extern void _setpwent(void);
 extern void _endpwent(void);
 extern struct passwd *_getpwent(void);
 extern struct passwd *_getpwnam(const char *name);
-extern struct passwd *_getpwuid(int uid);
+extern struct passwd *_getpwuid(uid_t uid);
 
 /* YP access functions */
 extern void yp_setpwent(void);
 extern void yp_endpwent(void);
 extern struct passwd *yp_getpwent(void);
 extern struct passwd *yp_getpwnam(const char *name);
-extern struct passwd *yp_getpwuid(int uid);
+extern struct passwd *yp_getpwuid(uid_t uid);
 
 /* NIS+ access functions */
 extern void nis_setpwent(void);
 extern void nis_endpwent(void);
 extern struct passwd *nis_getpwent(void);
 extern struct passwd *nis_getpwnam(const char *name);
-extern struct passwd *nis_getpwuid(int uid);
+extern struct passwd *nis_getpwuid(uid_t uid);
 
 /* DNS/Hesiod access functions */
 extern void dns_setpwent(void);
 extern void dns_endpwent(void);
 extern struct passwd *dns_getpwent(void);
 extern struct passwd *dns_getpwnam(const char *name);
-extern struct passwd *dns_getpwuid(int uid);
+extern struct passwd *dns_getpwuid(uid_t uid);
 
 /* Name Service Switch access functions */
 extern void setpwent(void);
 extern void endpwent(void);
 extern struct passwd *getpwent(void);
 extern struct passwd *getpwnam(const char *name);
-extern struct passwd *getpwuid(int uid);
+extern struct passwd *getpwuid(uid_t uid);
 
 #endif
