@@ -50,7 +50,7 @@ struct passwd *dns_getpwent(void)
 }
 
 
-struct passwd *dns_getpwuid(int uid)
+struct passwd *dns_getpwuid(uid_t uid)
 {
     errno = ECONNREFUSED;
     return NULL;
