@@ -39,6 +39,61 @@ static nis_result *res = NULL;
 static nis_name *names = NULL;
 
 
+#define NISENTRYCOL(idx,col,res) \
+	((res)->objects.objects_val[(idx)].zo_data.objdata_u.en_data.en_cols.en_cols_val[(col)].ec_value.ec_value_val)
+
+
+
+static struct passwd *parse_result(nis_result *res)
+{
+    static struct passwd pwd;
+
+    
+    if (res == NULL)
+	return NULL;
+    
+    /*
+    ** Validate the returned data. Must be a successful lookup,
+    ** the number of objects returned must be exactly one,
+    ** the returned object must be of type ENTRY,
+    ** the ENTRY table must be of type 'passwd_tbl',
+    ** and it must contain atleast 7 slots.
+    **
+    ** This might be overkill...
+    **
+    ** Should probably set errno to some sane value
+    */
+    if ((res->status != NIS_SUCCESS &&
+	 res->status != NIS_S_SUCCESS) ||
+	res->objects.objects_len != 1 ||
+	res->objects.objects_val[0].zo_data.zo_type != ENTRY_OBJ ||
+	strcmp(res->objects.objects_val[0].zo_data.objdata_u.en_data.en_type,
+	       "passwd_tbl") != 0 ||
+	res->objects.objects_val[0].zo_data.objdata_u.en_data.en_cols.en_cols_len < 7)
+	
+	return NULL;
+
+    if (pwd.pw_name)
+	free(pwd.pw_name);
+    if (pwd.pw_passwd)
+	free(pwd.pw_passwd);
+    if (pwd.pw_gecos)
+	free(pwd.pw_gecos);
+    if (pwd.pw_dir)
+	free(pwd.pw_dir);
+    if (pwd.pw_shell)
+	free(pwd.pw_shell);
+    
+    pwd.pw_name   = xstrdup(NISENTRYCOL(0, 0, res));
+    pwd.pw_passwd = xstrdup(NISENTRYCOL(0, 1, res));
+    pwd.pw_uid = atoi(NISENTRYCOL(0, 2, res));
+    pwd.pw_gid = atoi(NISENTRYCOL(0, 3, res));
+    pwd.pw_gecos = xstrdup(NISENTRYCOL(0, 4, res));
+    pwd.pw_dir = xstrdup(NISENTRYCOL(0, 5, res));
+    pwd.pw_shell = xstrdup(NISENTRYCOL(0, 6, res));
+
+    return &pwd;
+}
 
 void nis_setpwent(void)
 {
@@ -57,15 +112,8 @@ void nis_endpwent(void)
     }
 }
 
-#define NISENTRYCOL(idx,col,res) \
-	((res)->objects.objects_val[(idx)].zo_data.objdata_u.en_data.en_cols.en_cols_val[(col)].ec_value.ec_value_val)
-
-
 struct passwd *nis_getpwent(void)
 {
-    static struct passwd pwd;
-    
-
     if (res == NULL)
     {
 	if (names)
@@ -80,107 +128,37 @@ struct passwd *nis_getpwent(void)
     else
 	res = nis_next_entry(names[0], &res->cookie);
 
-    if (res == NULL)
-	return NULL;
-
-    if (res->status != 0 && res->status != 1)
-    {
-	/* XXX errno ? XXX */
-	return NULL;
-    }
-
-/* XXX Should assert that the result returned really is valid passwd data */
-    
-    pwd.pw_name   = NISENTRYCOL(0, 0, res);
-    pwd.pw_passwd = NISENTRYCOL(0, 1, res);
-    pwd.pw_uid = atoi(NISENTRYCOL(0, 2, res));
-    pwd.pw_gid = atoi(NISENTRYCOL(0, 3, res));
-    pwd.pw_gecos = NISENTRYCOL(0, 4, res);
-    pwd.pw_dir = NISENTRYCOL(0, 5, res);
-    pwd.pw_shell = NISENTRYCOL(0, 6, res);
-
-    return &pwd;
+    return parse_result(res);
 }
 
 
 struct passwd *nis_getpwuid(uid_t uid)
 {
     nis_result *res;
-    static struct passwd pwd;
     char buf[81];
 
 
     sprintf(buf, "[uid=%d],passwd.org_dir", uid);
     
     res = nis_list(buf, EXPAND_NAME, NULL, NULL);
-    if (res == NULL)
-	return NULL;
-
-    if (res->status != 0 && res->status != 1)
-    {
-	/* XXX errno ? XXX */
-	return NULL;
-    }
-
-/* XXX Should assert that the result returned really is valid passwd data */
-    
-    pwd.pw_name   = NISENTRYCOL(0, 0, res);
-    pwd.pw_passwd = NISENTRYCOL(0, 1, res);
-    pwd.pw_uid = atoi(NISENTRYCOL(0, 2, res));
-    pwd.pw_gid = atoi(NISENTRYCOL(0, 3, res));
-    pwd.pw_gecos = NISENTRYCOL(0, 4, res);
-    pwd.pw_dir = NISENTRYCOL(0, 5, res);
-    pwd.pw_shell = NISENTRYCOL(0, 6, res);
-
-    return &pwd;
+    return parse_result(res);
 }
 
 
 struct passwd *nis_getpwnam(const char *name)
 {
     nis_result *res;
-    static struct passwd pwd;
     char buf[81];
 
 
     if (name == NULL || strlen(name) > 8)
-	/* XXX errno ? XXX */
 	return NULL;
     
     sprintf(buf, "[name=%s],passwd.org_dir", name);
     
     res = nis_list(buf, EXPAND_NAME, NULL, NULL);
-    if (res == NULL)
-    {
-	fprintf(stderr, "nis_getpwnam() failing in nis_list()\n");
-	return NULL;
-    }
-
-    if (res->status != 0 && res->status != 1)
-    {
-#if 0
-	fprintf(stderr, "nis_getpwnam(\"%s\") failing with status = %d\n",
-		name,
-		res->status);
-	fprintf(stderr, "    for query: nis_list(\"%s\")\n", buf);
-	nis_print_result(res);
-#endif
-	/* XXX errno ? XXX */
-	return NULL;
-    }
-
     
-/* XXX Should assert that the result returned really is valid passwd data */
-    
-    pwd.pw_name   = NISENTRYCOL(0, 0, res);
-    pwd.pw_passwd = NISENTRYCOL(0, 1, res);
-    pwd.pw_uid = atoi(NISENTRYCOL(0, 2, res));
-    pwd.pw_gid = atoi(NISENTRYCOL(0, 3, res));
-    pwd.pw_gecos = NISENTRYCOL(0, 4, res);
-    pwd.pw_dir = NISENTRYCOL(0, 5, res);
-    pwd.pw_shell = NISENTRYCOL(0, 6, res);
-
-    return &pwd;
+    return parse_result(res);
 }
 
 #endif /* ENABLE_NIS */
