@@ -175,7 +175,7 @@ struct group *yp_getgrent(void)
 }
 
 
-struct group *yp_getgrgid(int gid)
+struct group *yp_getgrgid(gid_t gid)
 {
     struct group *gr;
     char *map;
