@@ -25,7 +25,8 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include "nis_passwd.h"
+#include <pwd.h>
+
 extern void print_passwd(struct passwd *);
 
 
