@@ -308,6 +308,8 @@ int yp_match(const char *indomain,
     *outval = xstrdup(ypres->val.valdat_val, ypres->val.valdat_len);
     *outvallen = ypres->val.valdat_len;
 
+    xdr_free(xdr_ypresp_val, (char *) ypres);
+    
     return 0;
 }
 
@@ -354,6 +356,8 @@ int yp_first(const char *indomain,
     *outval = xstrdup(ypres->val.valdat_val, ypres->val.valdat_len);
     *outvallen = ypres->val.valdat_len;
 #endif
+    
+    xdr_free(xdr_ypresp_key_val, (char *) ypres);
 
     return 0;
 }
@@ -402,6 +406,8 @@ int yp_next(const char *indomain,
     *outval = xstrdup(ypres->val.valdat_val, ypres->val.valdat_len);
     *outvallen = ypres->val.valdat_len;
 #endif
+    
+    xdr_free(xdr_ypresp_key_val, (char *) ypres);
 
     return 0;
 }
@@ -517,6 +523,8 @@ int yp_order(char *indomain,
     
     *outorder = ypres->ordernum;
     
+    xdr_free(xdr_ypresp_order, (char *) ypres);
+    
     return 0;
 }
 
@@ -543,7 +551,9 @@ int yp_master(char *indomain,
 	return ypprot_err(ypres->stat);
     
     *outname = strdup(ypres->peer);
-    
+
+    xdr_free(xdr_ypresp_master, (char *) ypres);
+
     return 0;
 }
 
